==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/api/BotaniaFabricCapabilities.java <==
package vazkii.botania.api;

import net.fabricmc.fabric.api.lookup.v1.block.BlockApiLookup;
import net.fabricmc.fabric.api.lookup.v1.item.ItemApiLookup;
import net.minecraft.class_2350;
import net.minecraft.class_2960;
import net.minecraft.class_3902;
import vazkii.botania.api.block.ExoflameHeatable;
import vazkii.botania.api.block.HornHarvestable;
import vazkii.botania.api.block.HourglassTrigger;
import vazkii.botania.api.block.Wandable;
import vazkii.botania.api.item.AvatarWieldable;
import vazkii.botania.api.item.BlockProvider;
import vazkii.botania.api.item.CoordBoundItem;
import vazkii.botania.api.item.Relic;
import vazkii.botania.api.mana.ManaCollisionGhost;
import vazkii.botania.api.mana.ManaItem;
import vazkii.botania.api.mana.ManaReceiver;
import vazkii.botania.api.mana.ManaTrigger;
import vazkii.botania.api.mana.spark.SparkAttachable;

public final class BotaniaFabricCapabilities {
	public static final ItemApiLookup<AvatarWieldable, class_3902> AVATAR_WIELDABLE = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "avatar_wieldable"), AvatarWieldable.class, class_3902.class);
	public static final ItemApiLookup<BlockProvider, class_3902> BLOCK_PROVIDER = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "block_provider"), BlockProvider.class, class_3902.class);
	public static final ItemApiLookup<CoordBoundItem, class_3902> COORD_BOUND_ITEM = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "coord_bound_item"),
			CoordBoundItem.class, class_3902.class);
	public static final ItemApiLookup<ManaItem, class_3902> MANA_ITEM = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_item"),
			ManaItem.class, class_3902.class);
	public static final ItemApiLookup<Relic, class_3902> RELIC = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "relic"),
			Relic.class, class_3902.class);

	public static final BlockApiLookup<ExoflameHeatable, class_3902> EXOFLAME_HEATABLE = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "exoflame_heatable"), ExoflameHeatable.class, class_3902.class);
	public static final BlockApiLookup<HornHarvestable, class_3902> HORN_HARVEST = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "horn_harvestable"), HornHarvestable.class, class_3902.class);
	public static final BlockApiLookup<HourglassTrigger, class_3902> HOURGLASS_TRIGGER = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "hourglass_trigger"), HourglassTrigger.class, class_3902.class);
	public static final BlockApiLookup<ManaCollisionGhost, class_3902> MANA_GHOST = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_ghost"), ManaCollisionGhost.class, class_3902.class);
	public static final BlockApiLookup<ManaReceiver, /* @Nullable */ class_2350> MANA_RECEIVER = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_receiver"), ManaReceiver.class, class_2350.class);
	public static final BlockApiLookup<SparkAttachable, class_2350> SPARK_ATTACHABLE = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "spark_attachable"), SparkAttachable.class, class_2350.class);
	public static final BlockApiLookup<ManaTrigger, class_3902> MANA_TRIGGER = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_trigger"), ManaTrigger.class, class_3902.class);
	public static final BlockApiLookup<Wandable, class_3902> WANDABLE = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "wandable"), Wandable.class, class_3902.class);

	private BotaniaFabricCapabilities() {}
}

==> Botania-1.20.1-451-FABRIC-20251001.215410-13-sources.jar: vazkii/botania/api/BotaniaFabricCapabilities.java <==
package vazkii.botania.api;

import net.fabricmc.fabric.api.lookup.v1.block.BlockApiLookup;
import net.fabricmc.fabric.api.lookup.v1.item.ItemApiLookup;
import net.minecraft.class_2350;
import net.minecraft.class_2960;
import net.minecraft.class_3902;
import vazkii.botania.api.block.*;
import vazkii.botania.api.item.AvatarWieldable;
import vazkii.botania.api.item.BlockProvider;
import vazkii.botania.api.item.CoordBoundItem;
import vazkii.botania.api.item.Relic;
import vazkii.botania.api.mana.ManaCollisionGhost;
import vazkii.botania.api.mana.ManaItem;
import vazkii.botania.api.mana.ManaReceiver;
import vazkii.botania.api.mana.ManaTrigger;
import vazkii.botania.api.mana.spark.SparkAttachable;

public final class BotaniaFabricCapabilities {
	public static final ItemApiLookup<AvatarWieldable, class_3902> AVATAR_WIELDABLE = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "avatar_wieldable"), AvatarWieldable.class, class_3902.class);
	public static final ItemApiLookup<BlockProvider, class_3902> BLOCK_PROVIDER = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "block_provider"), BlockProvider.class, class_3902.class);
	public static final ItemApiLookup<CoordBoundItem, class_3902> COORD_BOUND_ITEM = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "coord_bound_item"),
			CoordBoundItem.class, class_3902.class);
	public static final ItemApiLookup<ManaItem, class_3902> MANA_ITEM = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_item"),
			ManaItem.class, class_3902.class);
	public static final ItemApiLookup<Relic, class_3902> RELIC = ItemApiLookup.get(new class_2960(BotaniaAPI.MODID, "relic"),
			Relic.class, class_3902.class);

	public static final BlockApiLookup<ExoflameHeatable, class_3902> EXOFLAME_HEATABLE = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "exoflame_heatable"), ExoflameHeatable.class, class_3902.class);
	public static final BlockApiLookup<HornHarvestable, class_3902> HORN_HARVEST = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "horn_harvestable"), HornHarvestable.class, class_3902.class);
	public static final BlockApiLookup<HourglassTrigger, class_3902> HOURGLASS_TRIGGER = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "hourglass_trigger"), HourglassTrigger.class, class_3902.class);
	public static final BlockApiLookup<ManaCollisionGhost, class_3902> MANA_GHOST = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_ghost"), ManaCollisionGhost.class, class_3902.class);
	public static final BlockApiLookup<ManaReceiver, /* @Nullable */ class_2350> MANA_RECEIVER = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_receiver"), ManaReceiver.class, class_2350.class);
	public static final BlockApiLookup<SparkAttachable, class_2350> SPARK_ATTACHABLE = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "spark_attachable"), SparkAttachable.class, class_2350.class);
	public static final BlockApiLookup<ManaTrigger, class_3902> MANA_TRIGGER = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "mana_trigger"), ManaTrigger.class, class_3902.class);
	public static final BlockApiLookup<Wandable, class_3902> WANDABLE = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "wandable"), Wandable.class, class_3902.class);
	public static final BlockApiLookup<PhantomInkableBlock, class_3902> PHANTOM_INKABLE = BlockApiLookup.get(new class_2960(BotaniaAPI.MODID, "phantom_inkable"), PhantomInkableBlock.class, class_3902.class);

	private BotaniaFabricCapabilities() {}
}
